


#include <glib-object.h>

/* enumerations from "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.x86_64/src/gthumb-3.2.9.1/extensions/file_tools/gth-image-rotator.h" */
#include "/usr/src/ports/gthumb/gthumb-3.2.9.1-4.x86_64/src/gthumb-3.2.9.1/extensions/file_tools/gth-image-rotator.h"
GType
gth_transform_resize_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTH_TRANSFORM_RESIZE_CLIP, "GTH_TRANSFORM_RESIZE_CLIP", "clip" },
      { GTH_TRANSFORM_RESIZE_BOUNDING_BOX, "GTH_TRANSFORM_RESIZE_BOUNDING_BOX", "bounding-box" },
      { GTH_TRANSFORM_RESIZE_CROP, "GTH_TRANSFORM_RESIZE_CROP", "crop" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GthTransformResize", values);
  }
  return etype;
}



